@@ -9,18 +9,15 @@ test_that("Custom queries give desired result", {
   needs_api()
   country <- endpoint("country")
   df <- country()
-  expect_is(df, "data.frame")
-  expect_gt(dim(df)[1], 0)
-  
+  expect_is(df, "tbl")
+
   df <- country("Oreochromis niloticus")
-  expect_is(df, "data.frame")
-  expect_gt(dim(df)[1], 0)
-  
+  expect_is(df, "tbl")
+
   references()
   
   df <- species_names(2)
-  expect_is(df, "data.frame")
-  expect_gt(dim(df)[1], 0)
-  
+  expect_is(df, "tbl")
+
 })
 
